from sqlalchemy import (
    Column,
    Integer,
    String,
    DateTime,
    Date,
    Float,
    JSON,
    Table,
    ForeignKey,
    BigInteger,
    Index,
    TIMESTAMP,
    UniqueConstraint,
)
from sqlalchemy import desc, asc, cast, text, func

from sqlalchemy.orm import relationship, Mapped, mapped_column, DeclarativeBase

from lecrapaud.db.session import get_db
from lecrapaud.db.models.base import Base


class Model(Base):

    id = Column(BigInteger, primary_key=True, index=True, autoincrement=True)
    created_at = Column(
        TIMESTAMP(timezone=True), server_default=func.now(), nullable=False
    )
    updated_at = Column(
        TIMESTAMP(timezone=True),
        server_default=func.now(),
        onupdate=func.now(),
        nullable=False,
    )
    name = Column(String(50), nullable=False)
    type = Column(String(50), nullable=False)

    __table_args__ = (UniqueConstraint("name", "type", name="uq_model_composite"),)



from lecrapaud.jobs import app
from lecrapaud.utils import logger


@app.task(
    bind=True,
    autoretry_for=(Exception,),
    retry_backoff=True,
    retry_kwargs={"max_retries": 5},
    acks_late=True,
)
def task_training_experiment(self):
    try:
        pass
    except Exception as e:
        logger.error(e)
        raise



"""

Revision ID: 86457e2f333f
Revises: c62251b129ed
Create Date: 2025-06-24 17:11:25.187876

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import mysql

# revision identifiers, used by Alembic.
revision: str = '86457e2f333f'
down_revision: Union[str, None] = 'c62251b129ed'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('lecrapaud_scores', sa.Column('thresholds', sa.JSON(), nullable=True))
    op.add_column('lecrapaud_scores', sa.Column('f1_at_threshold', sa.Float(), nullable=True))
    op.drop_column('lecrapaud_scores', 'threshold')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('lecrapaud_scores', sa.Column('threshold', mysql.FLOAT(), nullable=True))
    op.drop_column('lecrapaud_scores', 'f1_at_threshold')
    op.drop_column('lecrapaud_scores', 'thresholds')
    # ### end Alembic commands ###



from sqlalchemy import (
    Column,
    Integer,
    String,
    DateTime,
    Date,
    Float,
    JSON,
    Table,
    ForeignKey,
    BigInteger,
    Index,
    TIMESTAMP,
)
from sqlalchemy import desc, asc, cast, text, func

from sqlalchemy.orm import relationship, Mapped, mapped_column, DeclarativeBase

from lecrapaud.db.session import get_db
from lecrapaud.db.models.base import Base
from lecrapaud.db.models.feature_selection import (
    lecrapaud_feature_selection_association,
)


class Feature(Base):

    id = Column(BigInteger, primary_key=True, index=True, autoincrement=True)
    created_at = Column(
        TIMESTAMP(timezone=True), server_default=func.now(), nullable=False
    )
    updated_at = Column(
        TIMESTAMP(timezone=True),
        server_default=func.now(),
        onupdate=func.now(),
        nullable=False,
    )
    name = Column(String(50), nullable=False, unique=True)
    type = Column(String(50))

    feature_selections = relationship(
        "FeatureSelection",
        secondary=lecrapaud_feature_selection_association,
        back_populates="features",
        lazy="selectin",
    )
